@@ -28,541 +28,673 @@
 #include "conf.h"
 #include "track.h"
 
-int configcontinue=1;
-int confignochild=0;
+extern struct trackoptions track_template;
 
-struct config conf = {
-	DEF_WIDTH,
-	DEF_HEIGHT,
-	DEF_QUALITY,
-	DEF_CHANGES,
-	0,
-	1,
-	0,
-	0, /* snapshot_overwrite */
-	DEF_GAP,
-	DEF_MAXMPEGTIME, /* max_mpeg_time */
-	1, /* locate */
-	IN_DEFAULT,
-	0,
-	DEF_MAXFRAMERATE,
-	0,
-	0,
-	0,
-	DEF_NOISELEVEL,
-	0, /* min gap */
-	0, /* lightswitch */
-	0, /* jpg_cleanup */
-	1, /* night compensate */
-	0, /* adjust rate*/
-	0, /* real motion */
-	0, /* old layout */
-	0, /* low_cpu */
-	0, /* nochild (runtime not an option) */
-	0, /* autobright */
-	VIDEO_DEVICE,
-	NULL,	/* video loopback pipe */
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,	/* mask file */
-	NULL,	/* db */
-	NULL,	/* host */
-	NULL,	/* user */
-	NULL,	/* password */
-	NULL,	/* onsave command */
-	NULL,	/* onmpeg command */
-	NULL,	/* AXIS ip address */
-	NULL,	/* motion video pipe */
-	NULL,	/* realconfig file */
-	NULL,	/* Netcam user:pass */
-	NULL	/* Netcam path (can't quite call it a URL) */
+struct config conf_template = {
+	width:			DEF_WIDTH,
+	height:			DEF_HEIGHT,
+	quality:		DEF_QUALITY,
+	max_changes:		DEF_CHANGES,
+	always_diff:		0,
+	new_img:		1,
+	motion_img:		0,
+	snap_overwrite:		0,
+	gap:			DEF_GAP,
+	maxmpegtime:		DEF_MAXMPEGTIME,
+	locate:			1,
+	input:			IN_DEFAULT,
+	norm:			0,
+	frame_limit:		DEF_MAXFRAMERATE,
+	mpeg:			0,
+	quiet:			0,
+	ppm:			0,
+	noise:			DEF_NOISELEVEL,
+	mingap:			0,
+	lightswitch:		0,
+	jpg_cleanup:		0,
+	nightcomp:		1,
+	adjustrate:		0,
+	realmotion:		0,
+	oldlayout:		0,
+	low_cpu:		0,
+	nochild:		0,
+	autobright:		0,
+	roundrobing_frames:	1,
+	roundrobing_skip:	1,
+	post_capture:		0,
+	switchfilter:		0,
+	ffmpeg_cap_new:		0,
+	ffmpeg_cap_motion:	0,
+	ffmpeg_bps:		DEF_FFMPEG_BPS,
+	webcam_port:		0,
+	webcam_quality:		30,
+	webcam_motion:		0,
+	webcam_maxrate:		100,
+	frequency:		0,
+	timelaps:		0,
+	device:			VIDEO_DEVICE,
+	vidpipe:		NULL,
+	mail_address:		NULL,
+	sms_nr:			NULL,
+	filepath:		NULL,
+	externcommand:		NULL,
+	mask_file:		NULL,
+	mysql_db:		NULL,
+	mysql_host:		NULL,
+	mysql_user:		NULL,
+	mysql_password:		NULL,
+	onsavecommand:		NULL,
+	onmpegcommand:		NULL,
+	motionvidpipe:		NULL,
+	netcam_url:		NULL,
+	netcam_userpass:	NULL,
+	pgsql_db:		NULL,
+	pgsql_host:		NULL,
+	pgsql_user:		NULL,
+	pgsql_password:		NULL,
+	pgsql_port:		5432,
+	mpeg_encode_bin:	"/usr/local/bin/mpeg_encode",
+	drawtext_changes: 0,
+	drawtext_shots: 0,
+	drawtext_user:  NULL
 };
 
 
 
-static void copy_bool(char *, void *);
-static void copy_int(char *, void *);
-static void copy_string(char *, void *);
-static void config_realconfig(char *str, void *val);
+static struct context **copy_bool(struct context **, char *, int);
+static struct context **copy_int(struct context **, char *, int);
+static struct context **copy_string(struct context **, char *, int);
+static struct context **config_thread(struct context **cnt, char *str, int val);
+//static void config_realconfig(char *str, void *val);
 static void usage(void);
 
+/* Pointer magic to determine relative addresses of variables to a
+   struct context pointer */
+#define CNT_OFFSET(varname) ( \
+		(int)&((struct context *)NULL)->varname \
+	)
+#define CONF_OFFSET(varname) ( \
+		(int)&((struct context *)NULL)->conf.varname \
+	)
+#define TRACK_OFFSET(varname) ( \
+		(int)&((struct context *)NULL)->track.varname \
+	)
+
 config_param config_params[] = {
 	{
 	"always_changes",
-	&conf.always_diff,
+	CONF_OFFSET(always_diff),
 	copy_bool
 	},
 	{
-	"deamon",
-	&deamon,
+	"daemon",
+	CNT_OFFSET(daemon),
 	copy_bool
 	},
 	{
 	"snapshots",
-	&alarmtime,
+	CNT_OFFSET(alarmtime),
 	copy_int
 	},
 	{
 	"threshold",
-	&conf.max_changes,
+	CONF_OFFSET(max_changes),
 	copy_int
 	},
 	{
 	"framerate",
-	&conf.frame_limit,
+	CONF_OFFSET(frame_limit),
 	copy_int
 	},
 	{
 	"locate",
-	&conf.locate,
+	CONF_OFFSET(locate),
 	copy_bool
 	},
 	{
 	"output_motion",
-	&conf.motion_img,
+	CONF_OFFSET(motion_img),
 	copy_bool
 	},
 	{
 	"output_normal",
-	&conf.new_img,
+	CONF_OFFSET(new_img),
 	copy_bool
 	},
 	{
 	"target_dir",
-	&conf.filepath,
+	CONF_OFFSET(filepath),
 	copy_string
 	},
 	{
 	"videodevice",
-	&conf.device,
+	CONF_OFFSET(device),
 	copy_string
 	},
 	{
 	"input",
-	&conf.input,
+	CONF_OFFSET(input),
 	copy_int
 	},
 	{
 	"norm",
-	&conf.norm,
+	CONF_OFFSET(norm),
 	copy_int
 	},
 	{
 	"quality",
-	&conf.quality,
+	CONF_OFFSET(quality),
 	copy_int
 	},
 	{
 	"quiet",
-	&conf.quiet,
+	CONF_OFFSET(quiet),
 	copy_bool
 	},
 	{
 	"ppm",
-	&conf.ppm,
+	CONF_OFFSET(ppm),
 	copy_bool
 	},
 	{
 	"width",
-	&conf.width,
+	CONF_OFFSET(width),
 	copy_int
 	},
 	{
 	"height",
-	&conf.height,
+	CONF_OFFSET(height),
 	copy_int
 	},
 	{
 	"execute",
-	&conf.externcommand,
+	CONF_OFFSET(externcommand),
 	copy_string
 	},
 	{
 	"mail",
-	&conf.mail_address,
+	CONF_OFFSET(mail_address),
 	copy_string
 	},
 	{
 	"sms",
-	&conf.sms_nr,
+	CONF_OFFSET(sms_nr),
 	copy_string
 	},
 	{
 	"snapshot_overwrite",
-	&conf.snap_overwrite,
+	CONF_OFFSET(snap_overwrite),
 	copy_bool
 	},
 	{
 	"gap",
-	&conf.gap,
+	CONF_OFFSET(gap),
 	copy_int
 	},
 	{
 	"max_mpeg_time",
-	&conf.maxmpegtime,
+	CONF_OFFSET(maxmpegtime),
 	copy_int	
 	},
 	{
 	"minimum_gap",
-	&conf.mingap,
+	CONF_OFFSET(mingap),
 	copy_int
 	},
 	{
 	"mpeg_encode",
-	&conf.mpeg,
+	CONF_OFFSET(mpeg),
 	copy_bool
 	},
 	{
 	"noise_level",
-	&conf.noise,
+	CONF_OFFSET(noise),
 	copy_int
 	},
 	{
 	"mask_file",
-	&conf.mask_file,
+	CONF_OFFSET(mask_file),
 	copy_string
 	},
 	{
 	"lightswitch",
-	&conf.lightswitch,
+	CONF_OFFSET(lightswitch),
 	copy_bool
 	},
 	{
 	"video_pipe",
-	&conf.vidpipe,
+	CONF_OFFSET(vidpipe),
 	copy_string
 	},
 	{
 	"jpg_cleanup",
-	&conf.jpg_cleanup,
+	CONF_OFFSET(jpg_cleanup),
 	copy_bool
 	},
 	{
 	"onsave",
-	&conf.onsavecommand,
+	CONF_OFFSET(onsavecommand),
 	copy_string
 	},
 	{
 	"onmpeg",
-	&conf.onmpegcommand,
-	copy_string
-	},
-	{
-	"axis",
-	&conf.axis,
+	CONF_OFFSET(onmpegcommand),
 	copy_string
 	},
 	{
 	"motion_video_pipe",
-	&conf.motionvidpipe,
+	CONF_OFFSET(motionvidpipe),
 	copy_string
 	},
 	{
 	"night_compensate",
-	&conf.nightcomp,
+	CONF_OFFSET(nightcomp),
 	copy_bool
 	},
 	{
 	"adjust_rate",
-	&conf.adjustrate,
+	CONF_OFFSET(adjustrate),
 	copy_bool
 	},
 	{
 	"realmotion",
-	&conf.realmotion,
+	CONF_OFFSET(realmotion),
 	copy_bool
 	},
 	{
 	"oldlayout",
-	&conf.oldlayout,
+	CONF_OFFSET(oldlayout),
 	copy_bool
 	},
 	{
 	"low_cpu",
-	&conf.low_cpu,
+	CONF_OFFSET(low_cpu),
 	copy_bool
 	},
 	{
-	"realconfig",
-	&conf.realconfig,
-	config_realconfig
+	"thread",
+	0,
+	config_thread
 	},
 	{
 	"auto_brightness",
-	&conf.autobright,
+	CONF_OFFSET(autobright),
 	copy_bool
 	},
 	{
-	"netcam_userpass",
-	&conf.netcam_userpass,
+	"webcam_port",
+	CONF_OFFSET(webcam_port),
+	copy_int
+	},
+	{
+	"webcam_quality",
+	CONF_OFFSET(webcam_quality),
+	copy_int
+	},
+	{
+	"webcam_motion",
+	CONF_OFFSET(webcam_motion),
+	copy_bool
+	},
+	{
+	"webcam_maxrate",
+	CONF_OFFSET(webcam_maxrate),
+	copy_int
+	},
+	{
+	"mpeg_encode_bin",
+	CONF_OFFSET(mpeg_encode_bin),
 	copy_string
 	},
 	{
-	"netcam_path",
-	&conf.netcam_path,
+	"frequency",
+	CONF_OFFSET(frequency),
+	copy_int
+	},
+	{
+	"drawtext_changes",
+	CONF_OFFSET(drawtext_changes),
+	copy_bool
+	},
+	{
+	"drawtext_shots",
+	CONF_OFFSET(drawtext_shots),
+	copy_bool
+	},
+	{
+	"drawtext_user",
+	CONF_OFFSET(drawtext_user),
 	copy_string
 	},
+#ifdef HAVE_CURL
+	{
+	"netcam_url",
+	CONF_OFFSET(netcam_url),
+	copy_string
+	},
+	{
+	"netcam_userpass",
+	CONF_OFFSET(netcam_userpass),
+	copy_string
+	},
+#endif
 #ifdef HAVE_MYSQL
 	{
 	"mysql_db",
-	&conf.mysql_db,
+	CONF_OFFSET(mysql_db),
 	copy_string
 	},
 	{
 	"mysql_host",
-	&conf.mysql_host,
+	CONF_OFFSET(mysql_host),
 	copy_string
 	},
 	{
 	"mysql_user",
-	&conf.mysql_user,
+	CONF_OFFSET(mysql_user),
 	copy_string
 	},
 	{
 	"mysql_password",
-	&conf.mysql_password,
+	CONF_OFFSET(mysql_password),
 	copy_string
 	},
 #endif
 	{
 	"track_port",
-	&track.port,
+	TRACK_OFFSET(port),
 	copy_string	
 	},
 	{
 	"track_motorx",
-	&track.motorx,
+	TRACK_OFFSET(motorx),
 	copy_int
 	},
 	{
 	"track_maxx",
-	&track.maxx,
+	TRACK_OFFSET(maxx),
 	copy_int
 	},
 	{
 	"track_iomojo_id",
-	&track.iomojo_id,
+	TRACK_OFFSET(iomojo_id),
 	copy_int
 	},
-  { NULL, NULL , NULL }
+	{
+	"track_speed",
+	TRACK_OFFSET(speed),
+	copy_int
+	},
+	{
+	"track_stepsize",
+	TRACK_OFFSET(stepsize),
+	copy_int
+	},
+	{
+	"roundrobing_frames",
+	CONF_OFFSET(roundrobing_frames),
+	copy_int
+	},
+	{
+	"roundrobing_skip",
+	CONF_OFFSET(roundrobing_skip),
+	copy_int
+	},
+	{
+	"switchfilter",
+	CONF_OFFSET(switchfilter),
+	copy_bool
+	},
+	{
+	"post_capture",
+	CONF_OFFSET(post_capture),
+	copy_int
+	},
+#ifdef HAVE_PGSQL
+	{
+	"pgsql_db",
+	CONF_OFFSET(pgsql_db),
+	copy_string
+	},
+	{
+	"pgsql_host",
+	CONF_OFFSET(pgsql_host),
+	copy_string
+	},
+	{
+	"pgsql_user",
+	CONF_OFFSET(pgsql_user),
+	copy_string
+	},
+	{
+	"pgsql_password",
+	CONF_OFFSET(pgsql_password),
+	copy_string
+	},
+	{
+	"pgsql_port",
+	CONF_OFFSET(pgsql_port),
+	copy_int
+	},
+#endif
+#ifdef HAVE_FFMPEG
+	{
+	"ffmpeg_cap_new",
+	CONF_OFFSET(ffmpeg_cap_new),
+	copy_bool
+	},
+	{
+	"ffmpeg_cap_motion",
+	CONF_OFFSET(ffmpeg_cap_motion),
+	copy_bool
+	},
+	{
+	"ffmpeg_timelaps",
+	CONF_OFFSET(timelaps),
+	copy_bool
+	},
+	{
+	"ffmpeg_bps",
+	CONF_OFFSET(ffmpeg_bps),
+	copy_int
+	},
+#endif
+  { NULL, 0 , NULL }
 };
 
 
-static void conf_cmdline (void)
+static void conf_cmdline (struct context *cnt)
 {
+	struct config *conf=&cnt->conf;
 	int c;
 
-        while ((c=getopt(conf.argc, conf.argv, "A:a:BCc:d:DE:F:f:G:g:hi:lL:M:mNn:O:P:pQq:r:S:s:t:u:U:V:"))!=EOF) 
+        while ((c=getopt(conf->argc, conf->argv, "a:BCc:d:DE:F:f:G:g:hi:lL:M:mNn:O:P:pQq:r:S:s:t:u:U:V:w"))!=EOF)
                 switch (c) {
-			case 'A':
-				conf.axis=optarg;
-				break;                                                    
                         case 'a':                                               
-                                sscanf (optarg, "%d", &alarmtime);              
+                                sscanf (optarg, "%d", &cnt->alarmtime);              
                                 break;
 			case 'B':
-				conf.mpeg=1;
+				conf->mpeg=1;
 				break;                                          
                         case 'C':                                               
-                                conf.always_diff=1;                                  
+                                conf->always_diff=1;                                  
                                 break;                                          
                         case 'c':                                               
-                                sscanf (optarg, "%d", &conf.max_changes);            
+                                sscanf (optarg, "%d", &conf->max_changes);            
                                 break;                                          
                         case 'd':                                               
-                                conf.device=optarg;                                  
+                                conf->device=optarg;                                  
                                 break;                                          
                         case 'E':                                               
-                                conf.externcommand=optarg;                           
+                                conf->externcommand=optarg;                           
                                 break;                                          
                         case 'D':                                               
-                                deamon=1;                                       
+                                cnt->daemon=1;
                                 break;
 			case 'F':
-				conf.mask_file=optarg;
+				conf->mask_file=optarg;
 				break;                                          
                         case 'f':                                               
-                                sscanf (optarg, "%d", &conf.frame_limit);            
+                                sscanf (optarg, "%d", &conf->frame_limit);            
                                 break;
 			case 'G':
-				sscanf (optarg, "%d", &conf.mingap);
+				sscanf (optarg, "%d", &conf->mingap);
 				break;                                          
                         case 'g':                                               
-                                sscanf (optarg, "%d", &conf.gap);                    
+                                sscanf (optarg, "%d", &conf->gap);                    
                                 break;                                          
                         case 'i':                                               
-                                sscanf (optarg, "%d", &conf.input);                  
+                                sscanf (optarg, "%d", &conf->input);                  
                                 break;                                          
                         case 'l':                                               
-                                conf.locate=0;                                       
+                                conf->locate=0;                                       
                                 break;
 			case 'L':
-				sscanf (optarg, "%d", &conf.noise);
+				sscanf (optarg, "%d", &conf->noise);
 				break;                                          
                         case 'M':                                               
-                                conf.mail_address=optarg;                            
+                                conf->mail_address=optarg;                            
                                 break;                                          
                         case 'm':                                               
-                                conf.motion_img=1;                                   
+                                conf->motion_img=1;                                   
                                 break;                                          
                         case 'N':                                               
-                                conf.new_img=0;                                      
+                                conf->new_img=0;                                      
                                 break;                                          
                         case 'n':                                               
-                                if (!strcmp(optarg, "pal")) conf.norm=NORM_PAL;
-				if (!strcmp(optarg, "pal-nc")) conf.norm=NORM_PAL_NC;
-                                if (!strcmp(optarg, "ntsc")) conf.norm=NORM_NTSC;
-                                if (!strcmp(optarg, "secam")) conf.norm=NORM_SECAM; 
+                                if (!strcmp(optarg, "pal")) conf->norm=NORM_PAL;
+				if (!strcmp(optarg, "pal-nc")) conf->norm=NORM_PAL_NC;
+                                if (!strcmp(optarg, "ntsc")) conf->norm=NORM_NTSC;
+                                if (!strcmp(optarg, "secam")) conf->norm=NORM_SECAM; 
                                 break;
 			case 'O':
-				conf.onsavecommand=optarg;
+				conf->onsavecommand=optarg;
 				break;
 			case 'P':
-				conf.vidpipe=optarg;
+				conf->vidpipe=optarg;
 				break;
 			case 'p':
-				conf.ppm=1;
+				conf->ppm=1;
 				break;                                          
                         case 'S':                                               
-                                conf.sms_nr=optarg;                                  
+                                conf->sms_nr=optarg;                                  
                                 break;                                          
                         case 'q':                                               
-                                sscanf (optarg, "%d", &conf.quality);
+                                sscanf (optarg, "%d", &conf->quality);
                                 break;
 			case 'r':
 				/* Should already be handled */
 				break;
 		        case 'Q':
-			        conf.quiet=1;
+			        conf->quiet=1;
 			        break;
                         case 's':                                               
-                                sscanf (optarg, "%dx%d", &conf.width, &conf.height);      
+                                sscanf (optarg, "%dx%d", &conf->width, &conf->height);      
                                 break;                                          
                         case 't':                                               
-                                conf.filepath=optarg;                                
+                                conf->filepath=optarg;                                
                                 break;                                          
 			case 'u':
-				conf.netcam_userpass=optarg;
+				conf->netcam_userpass=optarg;
 				break;
 			case 'U':
-				conf.netcam_path=optarg;
+				conf->netcam_url=optarg;
 				break;
 			case 'V':
-				conf.motionvidpipe=optarg;
+				conf->motionvidpipe=optarg;
 				break;
 			case 'w':
-				conf.lightswitch=1;
+				conf->lightswitch=1;
 				break;
                         case 'h':                                               
                         /* Do the same as an invallid option, but without the   
                          * 'invalid option' error.... */                        
                         default:                                                
-                                usage();                                        
-                                exit(1);                                       
-                }                        
+				usage();                                        
+				exit(1);                                       
+		}
 	optind=1;
 }
 
-void realconfig_cmdline (void)
-{
-	int c;
-
-	opterr=0;
-        while ((c=getopt(conf.argc, conf.argv, "-r:"))!=EOF) 
-                switch (c) {
-			case 'r':
-				/* We should act like a 'child' and shouldn't
-				   multiply :) */
-				conf.nochild=1;
-                                conf.realconfig=optarg;
-                        default:
-				break;
-                }
-	optind=1;
-	opterr=1;
-}
-
 /*****************************************************************************/
 
-void conf_cmdparse(char *cmd, char *arg1)
+struct context **conf_cmdparse(struct context **cnt, char *cmd, char *arg1)
 {
 	int i = 0;
 
 	if(!cmd)
-		return;
+		return cnt;
   
 	while( config_params[i].param_name != NULL ) {
 		if(!strncasecmp(cmd, config_params[i].param_name , 255 + 50)) {
 			if(config_params[i].conf_value && !arg1)
-				return;
-			config_params[i].copy( arg1, config_params[i].conf_value );
-			return;
+				return cnt;
+			cnt=config_params[i].copy( cnt, arg1, config_params[i].conf_value );
+			return cnt;
 		}
 		i++;
         }
 
 	fprintf( stderr, "Unkown config option: \"%s\"\n", cmd ); 
-        return;
+        return cnt;
 }
 
-void conf_process(FILE *fp)
+struct context **conf_process(struct context **cnt, FILE *fp)
 {
 	char line[256], *cmd = NULL, *arg1 = NULL;
 
 	if (fp) {
-		while (fgets(line, 256, fp) && configcontinue) {
+		while (fgets(line, 256, fp)) {
 			if(!(line[0]=='#' || strlen(line)< 2)) {/*skipcomment*/
-				line[strlen(line) - 1] = 0; /*kill'\n'*/
+				if (line[strlen(line)-1]=='\n')
+					line[strlen(line) - 1] = 0; /*kill'\n'*/
 				cmd = strtok( line, "\t =" );
-				arg1 = strtok( NULL, "\t =");
-				conf_cmdparse(cmd, arg1);
+				arg1 = strtok( NULL, "\t ");
+				cnt=conf_cmdparse(cnt, cmd, arg1);
 			}
 		}
 		fclose(fp);
 	}
+	return cnt;
 }
 
 
 /**************************************************************************
     Main function, called from motion.c
 */
-int conf_load (void)
+struct context ** conf_load (struct context **cnt)
 {
 	FILE *fp;
-	char filename[2048]; // What is the maximum filelength anyways?
+	char filename[2048]; /* What is the maximum filelength anyways? */
+	int i;
+	char **argv=cnt[0]->conf.argv;
+	int argc=cnt[0]->conf.argc;
 
-	if (!conf.nochild)
-		realconfig_cmdline ();
+	memcpy(&cnt[0]->conf, &conf_template, sizeof(struct config));
+	memcpy(&cnt[0]->track, &track_template, sizeof(struct trackoptions));
+	cnt[0]->conf.argv=argv;
+	cnt[0]->conf.argc=argc;
 
 	sprintf(filename, "%s/.motion/motion.conf", getenv("HOME"));
       	fp = fopen ("motion.conf", "r");
 	if (!fp) {	/* specified file does not exist... try default file */
 		fp = fopen (filename, "r");
 		if (!fp) {
-			fp = fopen ("/etc/motion.conf", "r");
+			fp = fopen (sysconfdir"/motion.conf", "r");
 			if (!fp) {	/* there is no config file.... use defaults */
 				perror("no config file");
 			}
 		}
 	}
-	conf_process(fp);
+	cnt=conf_process(cnt, fp);
 
-	if (conf.realconfig) {
-		fp = fopen (conf.realconfig, "r");
-		if (!fp) {
-			perror("realconfig file not found, exitting");
-			exit(1);
-		}
-		conf_process(fp);
-	}
-	
-	conf_cmdline();
-	
-	/* Prevent any additional childs from being created on SIGHUP */
-	conf.nochild=1;
-	return 0;
+	i=-1;
+	while(cnt[++i])
+		conf_cmdline(cnt[i]);
+
+//	/* Prevent any additional childs from being created on SIGHUP */
+//	conf->nochild=1;
+	return cnt;
 }
 
 /************************************************************************
@@ -576,42 +708,85 @@ int conf_load (void)
  *                value.
  * @param value - points to the place where to store the value. 
 ************************************************************************/
-static void copy_bool (char *str, void * val)
+static struct context **copy_bool (struct context **cnt, char *str, int val)
 {
-	if ( !strcmp(str, "1") || 
-	     !strcasecmp(str, "yes") || 
-	     !strcasecmp(str,"on")) 
-	{
-		*((int *)val) = 1;
-	} else {
-		*((int *)val) = 0;
-	}
-}
-
-static void copy_int(char *str, void * val) {
-	*((int *)val) = atoi(str);
-}
-
-static void copy_string(char *str, void * val) {
-	*(char **)val=malloc(255);
-	strncpy(*(char **)val, str, 255);	
-}
-
-static void config_realconfig(char *str, void *val)
-{
-	if (conf.nochild)
-		return;
-
-	if (conf.realconfig) {
-		if (!fork()) {
-			setpgrp();
-			return;
-		} else { 
-			free(conf.realconfig);
+	void *tmp;
+	int i;
+	
+	i=-1;
+	while(cnt[++i]) {
+		tmp=(void *)cnt[i]+(int)val;
+		if ( !strcmp(str, "1") || 
+		     !strcasecmp(str, "yes") || 
+		     !strcasecmp(str,"on")) 
+		{
+			*((int *)tmp) = 1;
+		} else {
+			*((int *)tmp) = 0;
 		}
+		if (cnt[0]->threadnr)
+			return cnt;
 	}
-	conf.realconfig=malloc(255);
-	strncpy(conf.realconfig, str, 255);
+	return cnt;
+}
+
+static struct context ** copy_int(struct context **cnt, char *str, int val)
+{
+	void *tmp;
+	int i;
+	
+	i=-1;
+	while(cnt[++i]) {
+		tmp=(void *)cnt[i]+val;
+		*((int *)tmp) = atoi(str);
+		if (cnt[0]->threadnr)
+			return cnt;
+	}
+	return cnt;
+}
+
+static struct context **copy_string(struct context **cnt, char *str, int val)
+{
+	void *tmp;
+	int i;
+	
+	i=-1;
+	while(cnt[++i]) {
+		tmp=(void *)cnt[i]+val;
+		*(char **)tmp=malloc(255);
+		strncpy(*(char **)tmp, str, 255);
+		if (cnt[0]->threadnr)
+			return cnt;
+	}
+	return cnt;
+}
+
+static struct context **config_thread(struct context **cnt, char *str, int val)
+{
+	int i;
+	FILE *fp;
+
+	printf("config_thread\n");
+	if (cnt[0]->threadnr)
+		return cnt;
+
+	fp=fopen(str, "r");
+	if (!fp) {
+		perror("thread config file not found");
+		return cnt;
+	}
+
+	i=-1;
+	while (cnt[++i]);
+	cnt=realloc(cnt, sizeof(struct context *)*(i+2));
+	cnt[i]=malloc(sizeof(struct context));
+	memcpy(cnt[i], cnt[0], sizeof(struct context));
+	cnt[i]->threadnr=i;
+	cnt[i+1]=NULL;
+printf("%d\n", i);
+	conf_process(cnt+i, fp);
+	
+	return cnt;
 }
 
 static void usage (void)
@@ -634,18 +809,18 @@ static void usage (void)
 	printf("-p\t\tOutput ppm images instead of jpeg, uses a lot of diskspace\n");
         printf("-t target dir\tdestination for snapshots.\n");
 	printf("-Q\t\tBe quiet, don't output beeps when detecting motion\n");
-	printf("-r filename\tRealconfig file to use\n");
 	printf("-w\t\tActivate light switch filter\n");
         printf("\nDevice settings:\n");
-	printf("-A ipnr\t\tAXIS camera ip address, default: not set\n");
         printf("-d device\tvideo4linux capture device, default: "VIDEO_DEVICE"\n");
         printf("-i input\tinput channel to use, default: not set\n");
         printf("-n norm\t\tnorm to use (pal/ntsc/secam), default: pal\n");
 	printf("-P device\tvideo4linux video loopback input device, default: not set\n");
         printf("-q quality\tJPEG image quality, default: %d\n", DEF_QUALITY);
         printf("-s widthxheight\tPicture size, default: %dx%d\n", DEF_WIDTH, DEF_HEIGHT);
+#ifdef HAVE_CURL
 	printf("-u user:pass\tNetwork camera username and password, default: none\n");
-	printf("-U path\t\tNetwork camera path for download, default: for old Axis 2100\n");
+	printf("-U url\t\tNetwork camera url for download, default: none\n");
+#endif
 	printf("-V device\tvideo4linux video loopback input device for motion frames,\n");
 	printf("\t\tdefault: not set.");
         printf("\nActions:\n");
