@@ -15,9 +15,6 @@
 #ifndef _INCLUDE_CONF_H
 #define _INCLUDE_CONF_H
 
-extern int deamon;
-extern int alarmtime;
-
 /* 
     more parameters may be added later.
  */
@@ -50,6 +47,19 @@ struct config {
 	int low_cpu;
 	int nochild;
 	int autobright;
+	int roundrobing_frames;
+	int roundrobing_skip;
+	int post_capture;
+	int switchfilter;
+	int ffmpeg_cap_new;
+	int ffmpeg_cap_motion;
+	int ffmpeg_bps;
+	int webcam_port;
+	int webcam_quality;
+	int webcam_motion;
+	int webcam_maxrate;
+	int frequency;
+	int timelaps;
 	char *device;
 	char *vidpipe;
 	char *mail_address;
@@ -63,11 +73,18 @@ struct config {
 	char *mysql_password;
 	char *onsavecommand;
 	char *onmpegcommand;
-	char *axis;
 	char *motionvidpipe;
-	char *realconfig;
+	char *netcam_url;
 	char *netcam_userpass;
-	char *netcam_path;
+	char *pgsql_db;
+	char *pgsql_host;
+	char *pgsql_user;
+	char *pgsql_password;
+	int pgsql_port;
+	char *mpeg_encode_bin;
+	int drawtext_changes;
+	int drawtext_shots;
+	char *drawtext_user;
 	int argc;
 	char **argv;
 };
@@ -77,20 +94,20 @@ extern struct config conf;
 /** 
  * typedef for a param copy function. 
  */
-typedef void (* conf_copy_func)(char *, void *) ;
+typedef struct context ** (* conf_copy_func)(struct context **, char *, int) ;
 
 /**
  * description for parameters in the config file
  */
 typedef struct {
-  char * param_name;         /* name for this parameter             */
-  void * conf_value;         /* pointer to a field in struct config */
-  conf_copy_func  copy;      /* a function to set the value in 'config'*/
+  char * param_name;	/* name for this parameter             */
+  int conf_value;	/* pointer to a field in struct context */
+  conf_copy_func  copy;	/* a function to set the value in 'config'*/
 } config_param; 
 
 
-extern struct config config;
-int conf_load (void);
-void conf_process (FILE *fp);
+//extern struct config config;
+struct context **conf_load (struct context **);
+//void conf_process (FILE *fp);
 
-#endif
+#endif /* _INCLUDE_CONF_H */
