@@ -17,14 +17,19 @@ struct trackoptions {
 	char *port;
 	int motorx;
 	int maxx;
+	int stepsize;
+	int speed;
 	int iomojo_id;
 };
 
-extern struct trackoptions track;
-
-int track_center(void);
-int track_move(int dev, int pipe, int mpipe, struct coord cent, struct images *imgs);
+int track_center(struct context *);
+int track_move(struct context *, int dev, int pipe, int mpipe, struct coord cent, struct images *imgs);
 
+/*
+	Some default values:
+ */
+#define TRACK_SPEED	255
+#define TRACK_STEPSIZE	40
 
 /*
 	Some defines for the Serial stepper motor:
